SELECT 100 Summary - Criterion.rs

## SELECT 100

### Violin Plot

This chart shows the relationship between function/parameter and iteration time. The thickness of the shaded region indicates the probability that a measurement of the given function/parameter would take a particular length of time.

#### SELECT 100/aiomysql

#### SELECT 100/asyncmy

#### SELECT 100/mysqlclient

#### SELECT 100/pymysql

#### SELECT 100/pyro-async

#### SELECT 100/pyro-sync